@@ -32,11 +32,13 @@ class NetFieldErrorException(Exception):
 def getAllNics():
     ret = []
     get_if_cmd = 'ip link|grep -v lo'
-    for line in os.popen(get_if_cmd):
+    stream = os.popen(get_if_cmd)
+    for line in stream:
         if re.match("^\d", line):
             s = line.split(":")
             name = s[1].strip();
             ret.append(name)
+    stream.close()
     return ret
 
 class Netctl(object):
