@@ -10,7 +10,7 @@ import psutil
 import memcache
 import uuid
 
-class FilesytemException(Exception):
+class FilesystemException(Exception):
     pass
 
 class MountPoint(object):
@@ -274,11 +274,11 @@ class Filesystems(object):
         :return: if successful
         """
         if device == None:
-            raise FilesytemException("device must not be null")
+            raise FilesystemException("device must not be null")
         if mountpoint == None:
-            raise FilesytemException("mountpoin must not be null")
+            raise FilesystemException("mountpoin must not be null")
         if type == None:
-            raise FilesytemException("type must not be null")
+            raise FilesystemException("type must not be null")
         uuid = None
         if useUuid:
             uuid = Filesystems.getUuid(device, generate=False)
@@ -360,11 +360,11 @@ class Filesystems(object):
         :return:
         """
         if device == None:
-            raise FilesytemException("device must not be null")
+            raise FilesystemException("device must not be null")
         if type == None:
-            raise FilesytemException("type must not be null")
+            raise FilesystemException("type must not be null")
         if type not in Filesystems.SUPPORTED_FILESYSTEMS:
-            raise FilesytemException("fs type %s is not supported. Supported types are %s" % (type, Filesystems.SUPPORTED_FILESYSTEMS))
+            raise FilesystemException("fs type %s is not supported. Supported types are %s" % (type, Filesystems.SUPPORTED_FILESYSTEMS))
         raid = self._isRaid(device)
         options = ""
         if raid:
@@ -388,7 +388,7 @@ class Filesystems(object):
         if out.rc == 0:
             return True
         else:
-            raise FilesytemException("error while formation %s. STDOUT: %s STDERR: %s CMD: %s" % (device, out.stdout, out.stderr, mkfs))
+            raise FilesystemException("error while formation %s. STDOUT: %s STDERR: %s CMD: %s" % (device, out.stdout, out.stderr, mkfs))
 
 
     @classmethod
