@@ -419,7 +419,6 @@ class UsersAndGroup(object):
         try:
             return self.getUserByAccount(userName) != None
         except SambaUserNotFound as e:
-            print(e)
             return False
 
     def groupExists(self, groupName):
@@ -575,7 +574,7 @@ class UsersAndGroup(object):
         :param members: a list of users in the group
         :return: the group details
         """
-        users = None
+        users = []
         if len(members) >= 1:
             for user in members:
                 if self.userExists(user):
