@@ -66,7 +66,7 @@ class NfsShareService(ShareService):
                             val = val.strip()
                             if key == 'exon_name':
                                 name = val
-                    options = optionString.split(',')
+                    options = optionString.strip().split(',')
                     rw = []
                     ro =[]
                     if "rw" in options:
